@@ -1,31 +1,31 @@
+#!/usr/bin/env python
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
-#
-# BitBake 'Build' implementation
-#
-# Core code for function execution and task handling in the
-# BitBake build tools.
-#
-# Copyright (C) 2003, 2004  Chris Larson
-#
-# Based on Gentoo's portage.py.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-#
-#Based on functions from the base bb module, Copyright 2003 Holger Schurig
+"""
+BitBake 'Build' implementation
 
-from bb import data, fetch, fatal, error, note, event, mkdirhier, utils
+Core code for function execution and task handling in the
+BitBake build tools.
+
+Copyright (C) 2003, 2004  Chris Larson
+
+Based on Gentoo's portage.py.
+
+This program is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free Software
+Foundation; either version 2 of the License, or (at your option) any later
+version.
+
+This program is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with
+
+Based on functions from the base bb module, Copyright 2003 Holger Schurig
+"""
+
+from bb import data, fetch, event, mkdirhier, utils
 import bb, os
 
 # events
@@ -147,7 +147,7 @@ def exec_func_shell(func, d):
 
     f = open(runfile, "w")
     f.write("#!/bin/sh -e\n")
-    if bb.msg.debug_level > 0: f.write("set -x\n")
+    if bb.msg.debug_level['default'] > 0: f.write("set -x\n")
     data.emit_env(f, d)
 
     f.write("cd %s\n" % os.getcwd())
@@ -155,18 +155,18 @@ def exec_func_shell(func, d):
     f.close()
     os.chmod(runfile, 0775)
     if not func:
-        error("Function not specified")
+        bb.msg.error(bb.msg.domain.Build, "Function not specified")
         raise FuncFailed()
 
     # open logs
     si = file('/dev/null', 'r')
     try:
-        if bb.msg.debug_level > 0:
+        if bb.msg.debug_level['default'] > 0:
             so = os.popen("tee \"%s\"" % logfile, "w")
         else:
             so = file(logfile, 'w')
     except OSError, e:
-        bb.error("opening log file: %s" % e)
+        bb.msg.error(bb.msg.domain.Build, "opening log file: %s" % e)
         pass
 
     se = so
@@ -211,14 +211,14 @@ def exec_func_shell(func, d):
         os.close(ose[0])
 
     if ret==0:
-        if bb.msg.debug_level > 0:
+        if bb.msg.debug_level['default'] > 0:
             os.remove(runfile)
 #            os.remove(logfile)
         return
     else:
-        error("function %s failed" % func)
+        bb.msg.error(bb.msg.domain.Build, "function %s failed" % func)
         if data.getVar("BBINCLUDELOGS", d):
-            error("log data follows (%s)" % logfile)
+            bb.msg.error(bb.msg.domain.Build, "log data follows (%s)" % logfile)
             f = open(logfile, "r")
             while True:
                 l = f.readline()
@@ -228,7 +228,7 @@ def exec_func_shell(func, d):
                 print '| %s' % l
             f.close()
         else:
-            error("see log in %s" % logfile)
+            bb.msg.error(bb.msg.domain.Build, "see log in %s" % logfile)
         raise FuncFailed( logfile )
 
 
@@ -279,13 +279,15 @@ def exec_task(task, d):
                 task_cache.append(item)
                 data.setVar('_task_cache', task_cache, d)
             except FuncFailed, reason:
-                note( "Task failed: %s" % reason )
+                bb.msg.note(1, bb.msg.domain.Build, "Task failed: %s" % reason )
                 failedevent = TaskFailed(item, d)
                 event.fire(failedevent)
                 raise EventException("Function failed in task: %s" % reason, failedevent)
 
-    # execute
-    task_graph.walkdown(task, execute)
+    if data.getVarFlag(task, 'dontrundeps', d):
+        execute(None, task)
+    else:
+        task_graph.walkdown(task, execute)
 
     # make stamp, or cause event and raise exception
     if not data.getVarFlag(task, 'nostamp', d):
