@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 """
@@ -17,25 +18,25 @@ to have faster update_data and expandKeys operations.
 
 This is a treade-off between speed and memory again but
 the speed is more critical here.
-"""
 
-# Copyright (C) 2003, 2004  Chris Larson
-# Copyright (C) 2005        Holger Hans Peter Freyther
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-#
-#Based on functions from the base bb module, Copyright 2003 Holger Schurig
+Copyright (C) 2003, 2004  Chris Larson
+Copyright (C) 2005        Holger Hans Peter Freyther
+
+This program is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free Software
+Foundation; either version 2 of the License, or (at your option) any later
+version.
+
+This program is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with
+this program; if not, write to the Free Software Foundation, Inc., 59 Temple
+Place, Suite 330, Boston, MA 02111-1307 USA. 
+
+Based on functions from the base bb module, Copyright 2003 Holger Schurig
+"""
 
 import sys, os, re, time, types
 if sys.argv[0][-5:] == "pydoc":
@@ -44,7 +45,8 @@ else:
     path = os.path.dirname(os.path.dirname(sys.argv[0]))
 sys.path.insert(0,path)
 
-from bb import note, debug, data_smart
+from bb import data_smart
+import bb
 
 _dict_type = data_smart.DataSmart
 
@@ -362,15 +364,10 @@ def emit_var(var, o=sys.__stdout__, d = init(), all=False):
     if not val:
         return 0
 
-    varExpanded = expand(var, d)
-
     if getVarFlag(var, "func", d):
 #       NOTE: should probably check for unbalanced {} within the var
-        o.write("%s() {\n%s\n}\n" % (varExpanded, val))
+        o.write("%s() {\n%s\n}\n" % (var, val))
     else:
-        if getVarFlag(var, "unexport", d):
-            o.write('unset %s\n' % varExpanded)
-            return 1
         if getVarFlag(var, "export", d):
             o.write('export ')
         else:
@@ -379,7 +376,7 @@ def emit_var(var, o=sys.__stdout__, d = init(), all=False):
 #       if we're going to output this within doublequotes,
 #       to a shell, we need to escape the quotes in the var
         alter = re.sub('"', '\\"', val.strip())
-        o.write('%s="%s"\n' % (varExpanded, alter))
+        o.write('%s="%s"\n' % (var, alter))
     return 1
 
 
@@ -465,7 +462,7 @@ def update_data(d):
         file://append.foo;patch=1 file://other.foo;patch=1
 
     """
-    debug(2, "update_data()")
+    bb.msg.debug(2, bb.msg.domain.Data, "update_data()")
 
     # now ask the cookie monster for help
     #print "Cookie Monster"
@@ -503,7 +500,7 @@ def update_data(d):
             try:
                 d[name] = d[var]
             except:
-                note ("Untracked delVar")
+                bb.msg.note(1, bb.msg.domain.Data, "Untracked delVar")
 
     # now on to the appends and prepends
     if d._special_values.has_key('_append'):
