@@ -1,33 +1,30 @@
+#!/usr/bin/env python
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 """
 BitBake 'Fetch' implementations
 
-This implementation is for svn. It is based on the cvs implementation.
+Classes for obtaining upstream sources for the
+BitBake build tools.
 
+Copyright (C) 2003, 2004  Chris Larson
+
+This program is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free Software
+Foundation; either version 2 of the License, or (at your option) any later
+version.
+
+This program is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with
+this program; if not, write to the Free Software Foundation, Inc., 59 Temple
+Place, Suite 330, Boston, MA 02111-1307 USA. 
+
+Based on functions from the base bb module, Copyright 2003 Holger Schurig
 """
 
-# Copyright (C) 2004 Marcin Juszkiewicz
-#
-#   Classes for obtaining upstream sources for the
-#   BitBake build tools.
-#   Copyright (C) 2003, 2004  Chris Larson
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-#
-# Based on functions from the base bb module, Copyright 2003 Holger Schurig
-
 import os, re
 import sys
 import bb
@@ -63,12 +60,6 @@ class Svn(Fetch):
 
         date = Fetch.getSRCDate(d)
 
-        if 'srcdate' in parm:
-            date = parm['srcdate']
-
-        if revision:
-            date = ""
-
         return os.path.join(data.getVar("DL_DIR", d, 1),data.expand('%s_%s_%s_%s_%s.tar.gz' % ( module.replace('/', '.'), host, path.replace('/', '.'), revision, date), d))
     localpath = staticmethod(localpath)
 
@@ -101,30 +92,12 @@ class Svn(Fetch):
 
 #           setup svn options
             options = []
-
-            date = Fetch.getSRCDate(d)
-
-            if 'srcdate' in parm:
-                date = parm['srcdate']
-
-            revision = ""
             if 'rev' in parm:
                 revision = parm['rev']
-            
-            if revision:
-                options.append("-r %s" % revision)
-            elif date != "now":
-                options.append("-r {%s}" % date)
+            else:
+                revision = ""
 
-            if revision:
-                date = ""
-
-
-            if user:
-                options.append("--username %s" % user)
-
-            if pswd:
-                options.append("--password %s" % pswd)
+            date = Fetch.getSRCDate(d)
 
             if "proto" in parm:
                 proto = parm["proto"]
@@ -141,7 +114,7 @@ class Svn(Fetch):
 
             # try to use the tarball stash
             if Fetch.check_for_tarball(d, tarfn, dldir, date):
-                bb.debug(1, "%s already exists or was mirrored, skipping svn checkout." % tarfn)
+                bb.msg.debug(1, bb.msg.domain.Fetcher, "%s already exists or was mirrored, skipping svn checkout." % tarfn)
                 continue
 
             olddir = os.path.abspath(os.getcwd())
@@ -149,6 +122,12 @@ class Svn(Fetch):
 
             svnroot = host + path
 
+            # either use the revision, or SRCDATE in braces, or nothing for SRCDATE = "now"
+            if revision:
+                options.append("-r %s" % revision)
+            elif date != "now":
+                options.append("-r {%s}" % date)
+
             data.setVar('SVNROOT', "%s://%s/%s" % (proto, svnroot, module), localdata)
             data.setVar('SVNCOOPTS', " ".join(options), localdata)
             data.setVar('SVNMODULE', module, localdata)
@@ -159,29 +138,30 @@ class Svn(Fetch):
                 svncmd = "svn_RSH=\"%s\" %s" % (svn_rsh, svncmd)
                 svnupcmd = "svn_RSH=\"%s\" %s" % (svn_rsh, svnupcmd)
 
-            pkg = data.expand('${PN}', d)
-            pkgdir = os.path.join(data.expand('${SVNDIR}', localdata), pkg)
-            moddir = os.path.join(pkgdir, module)
-            bb.debug(2, "Fetch: checking for module directory '%s'" % moddir)
+            pkg=data.expand('${PN}', d)
+            pkgdir=os.path.join(data.expand('${SVNDIR}', localdata), pkg)
+            moddir=os.path.join(pkgdir, module)
+            bb.msg.debug(2, bb.msg.domain.Fetcher, "Fetch: checking for module directory '" + moddir + "'")
 
-            if os.access(os.path.join(moddir, '.svn'), os.R_OK):
-                bb.note("Update " + loc)
-                # update sources there
+            if os.access(os.path.join(moddir,'.svn'), os.R_OK):
+                bb.msg.note(1, bb.msg.domain.Fetcher, "Update " + loc)
+    		# update sources there
                 os.chdir(moddir)
-                bb.debug(1, "Running %s" % svnupcmd)
+                bb.msg.debug(1, bb.msg.domain.Fetcher, "Running %s" % svnupcmd)
                 myret = os.system(svnupcmd)
             else:
-                bb.note("Fetch " + loc)
-#               check out sources there
+                bb.msg.note(1, bb.msg.domain.Fetcher, "Fetch " + loc)
+    		# check out sources there
                 bb.mkdirhier(pkgdir)
                 os.chdir(pkgdir)
-                bb.debug(1, "Running %s" % svncmd)
+                bb.msg.debug(1, bb.msg.domain.Fetcher, "Running %s" % svncmd)
                 myret = os.system(svncmd)
+
             if myret != 0:
                 raise FetchError(module)
 
             os.chdir(pkgdir)
-#           tar them up to a defined filename
+	    # tar them up to a defined filename
             myret = os.system("tar -czf %s %s" % (os.path.join(dldir,tarfn), os.path.basename(module)))
             if myret != 0:
                 try:
@@ -189,4 +169,5 @@ class Svn(Fetch):
                 except OSError:
                     pass
             os.chdir(olddir)
+
         del localdata
