@@ -1,33 +1,29 @@
 #!/usr/bin/env python
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
-"""
-   class for handling .bb files
+"""class for handling .bb files
 
    Reads a .bb file and obtains its metadata
 
-"""
-
-
-#  Copyright (C) 2003, 2004  Chris Larson
-#  Copyright (C) 2003, 2004  Phil Blundell
-#   
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+   Copyright (C) 2003, 2004  Chris Larson
+   Copyright (C) 2003, 2004  Phil Blundell
+   
+   This program is free software; you can redistribute it and/or modify it under
+   the terms of the GNU General Public License as published by the Free Software
+   Foundation; either version 2 of the License, or (at your option) any later
+   version.
+   
+   This program is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+   FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+   
+   You should have received a copy of the GNU General Public License along with
+   this program; if not, write to the Free Software Foundation, Inc., 59 Temple
+   Place, Suite 330, Boston, MA 02111-1307 USA.""" 
 
 import re, bb, os, sys, time
 import bb.fetch, bb.build, bb.utils
-from bb import debug, data, fetch, fatal, methodpool
+from bb import data, fetch, methodpool
 
 from ConfHandler import include, localpath, obtain, init
 from bb.parse import ParseError
@@ -64,11 +60,11 @@ def inherit(files, d):
             file = os.path.join('classes', '%s.bbclass' % file)
 
         if not file in __inherit_cache.split():
-            debug(2, "BB %s:%d: inheriting %s" % (fn, lineno, file))
+            bb.msg.debug(2, bb.msg.domain.Parsing, "BB %s:%d: inheriting %s" % (fn, lineno, file))
             __inherit_cache += " %s" % file
-            data.setVar('__inherit_cache', __inherit_cache, d)
             include(fn, file, d)
-            __inherit_cache = data.getVar('__inherit_cache', d) or ""
+    data.setVar('__inherit_cache', __inherit_cache, d)
+
 
 def handle(fn, d, include = 0):
     global __func_start_regexp__, __inherit_regexp__, __export_func_regexp__, __addtask_regexp__, __addhandler_regexp__, __infunc__, __body__, __bbpath_found__, __residue__
@@ -79,9 +75,9 @@ def handle(fn, d, include = 0):
     __residue__ = []
 
     if include == 0:
-        debug(2, "BB " + fn + ": handle(data)")
+        bb.msg.debug(2, bb.msg.domain.Parsing, "BB " + fn + ": handle(data)")
     else:
-        debug(2, "BB " + fn + ": handle(data, include)")
+        bb.msg.debug(2, bb.msg.domain.Parsing, "BB " + fn + ": handle(data, include)")
 
     (root, ext) = os.path.splitext(os.path.basename(fn))
     base_name = "%s%s" % (root,ext)
@@ -156,7 +152,7 @@ def handle(fn, d, include = 0):
                     if t:
                         data.setVar('T', t, d)
                 except Exception, e:
-                    bb.debug(1, "executing anonymous function: %s" % e)
+                    bb.msg.debug(1, bb.msg.domain.Parsing, "executing anonymous function: %s" % e)
                     raise
             data.delVar("__anonqueue", d)
             data.delVar("__anonfunc", d)
@@ -367,8 +363,6 @@ def vars_from_file(mypkg, d):
     myfile = os.path.splitext(os.path.basename(mypkg))
     parts = myfile[0].split('_')
     __pkgsplit_cache__[mypkg] = parts
-    if len(parts) > 3:
-        raise ParseError("Unable to generate default variables from the filename: %s (too many underscores)" % mypkg)
     exp = 3 - len(parts)
     tmplist = []
     while exp != 0:
@@ -380,7 +374,7 @@ def vars_from_file(mypkg, d):
 def set_additional_vars(file, d, include):
     """Deduce rest of variables, e.g. ${A} out of ${SRC_URI}"""
 
-    debug(2,"BB %s: set_additional_vars" % file)
+    bb.msg.debug(2, bb.msg.domain.Parsing, "BB %s: set_additional_vars" % file)
 
     src_uri = data.getVar('SRC_URI', d)
     if not src_uri:
