@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 ##########################################################################
@@ -5,18 +6,17 @@
 # Copyright (C) 2005-2006 Michael 'Mickey' Lauer <mickey@Vanille.de>
 # Copyright (C) 2005-2006 Vanille Media
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU General Public License as published by the Free Software
+# Foundation; version 2 of the License.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
+# Place, Suite 330, Boston, MA 02111-1307 USA.
 #
 ##########################################################################
 #
@@ -57,8 +57,7 @@ try:
 except NameError:
     from sets import Set as set
 import sys, os, readline, socket, httplib, urllib, commands, popen2, copy, shlex, Queue, fnmatch
-import bb
-from bb import data, parse, build, fatal
+from bb import data, parse, build, fatal, cache, taskdata, runqueue, providers as Providers
 
 __version__ = "0.5.3.1"
 __credits__ = """BitBake Shell Version %s (C) 2005 Michael 'Mickey' Lauer <mickey@Vanille.de>
@@ -108,7 +107,7 @@ class BitBakeShellCommands:
         preferred = data.getVar( "PREFERRED_PROVIDER_%s" % item, cooker.configuration.data, 1 )
         if not preferred: preferred = item
         try:
-            lv, lf, pv, pf = bb.providers.findBestProvider(preferred, cooker.configuration.data, cooker.status, cooker.build_cache_fail)
+            lv, lf, pv, pf = Providers.findBestProvider(preferred, cooker.configuration.data, cooker.status, cooker.build_cache_fail)
         except KeyError:
             if item in cooker.status.providers:
                 pf = cooker.status.providers[item][0]
@@ -156,14 +155,39 @@ class BitBakeShellCommands:
         cooker.build_cache = []
         cooker.build_cache_fail = []
 
-        for name in names:
-            try:
-                cooker.buildProvider( name, data.getVar("BUILD_ALL_DEPS", cooker.configuration.data, True) )
-            except build.EventException, e:
-                print "ERROR: Couldn't build '%s'" % name
-                global last_exception
-                last_exception = e
-                break
+        td = taskdata.TaskData()
+
+        try:
+            tasks = []
+            for name in names:
+                td.add_provider(cooker.configuration.data, cooker.status, name)
+                providers = td.get_provider(name)
+
+                if len(providers) == 0:
+                    raise Providers.NoProvider
+
+                tasks.append([name, "do_%s" % cooker.configuration.cmd])
+
+            td.add_unresolved(cooker.configuration.data, cooker.status)
+            
+            rq = runqueue.RunQueue()
+            rq.prepare_runqueue(cooker.configuration.data, cooker.status, td, tasks)
+            rq.execute_runqueue(cooker, cooker.configuration.data, cooker.status, td, tasks)
+
+        except Providers.NoProvider:
+            print "ERROR: No Provider"
+            global last_exception
+            last_exception = Providers.NoProvider
+
+        except runqueue.TaskFailure, (fnid, fn, taskname):
+            print "ERROR: '%s, %s' failed" % (fn, taskname)
+            global last_exception
+            last_exception = runqueue.TaskFailure
+
+        except build.EventException, e:
+            print "ERROR: Couldn't build '%s'" % names
+            global last_exception
+            last_exception = e
 
         cooker.configuration.cmd = oldcmd
 
@@ -233,7 +257,7 @@ class BitBakeShellCommands:
             item = data.getVar('PN', bbfile_data, 1)
             data.setVar( "_task_cache", [], bbfile_data ) # force
             try:
-                cooker.tryBuildPackage( os.path.abspath( bf ), item, bbfile_data )
+                cooker.tryBuildPackage( os.path.abspath( bf ), item, cmd, bbfile_data, True )
             except build.EventException, e:
                 print "ERROR: Couldn't build '%s'" % name
                 global last_exception
@@ -255,8 +279,7 @@ class BitBakeShellCommands:
 
     def fileRebuild( self, params ):
         """Rebuild (clean & build) a .bb file"""
-        self.fileClean( params )
-        self.fileBuild( params )
+        self.fileBuild( params, "rebuild" )
     fileRebuild.usage = "<bbfile>"
 
     def fileReparse( self, params ):
@@ -265,7 +288,7 @@ class BitBakeShellCommands:
         print "SHELL: Parsing '%s'" % bbfile
         parse.update_mtime( bbfile )
         cooker.bb_cache.cacheValidUpdate(bbfile)
-        fromCache = cooker.bb_cache.loadData(bbfile, cooker)
+        fromCache = cooker.bb_cache.loadData(bbfile, cooker.configuration.data)
         cooker.bb_cache.sync()
         if False: #fromCache:
             print "SHELL: File has not been updated, not reparsing"
@@ -393,12 +416,13 @@ SRC_URI = ""
 
     def parse( self, params ):
         """(Re-)parse .bb files and calculate the dependency graph"""
-        cooker.status = cooker.ParsingStatus()
+        cooker.status = cache.CacheData()
         ignore = data.getVar("ASSUME_PROVIDED", cooker.configuration.data, 1) or ""
         cooker.status.ignored_dependencies = set( ignore.split() )
         cooker.handleCollections( data.getVar("BBFILE_COLLECTIONS", cooker.configuration.data, 1) )
 
-        cooker.collect_bbfiles( cooker.myProgressCallback )
+        (filelist, masked) = cooker.collect_bbfiles()
+        cooker.parse_bbfiles(filelist, masked, cooker.myProgressCallback)
         cooker.buildDepgraph()
         global parsed
         parsed = True
@@ -426,7 +450,7 @@ SRC_URI = ""
         name, var = params
         bbfile = self._findProvider( name )
         if bbfile is not None:
-            the_data = cooker.bb_cache.loadDataFull(bbfile, cooker)
+            the_data = cooker.bb_cache.loadDataFull(bbfile, cooker.configuration.data)
             value = the_data.getVar( var, 1 )
             print value
         else:
@@ -530,7 +554,8 @@ SRC_URI = ""
         if not preferred: preferred = item
 
         try:
-            lv, lf, pv, pf = bb.providers.findBestProvider(preferred, cooker.configuration.data, cooker.status, cooker.build_cache_fail)
+            lv, lf, pv, pf = Providers.findBestProvider(preferred, cooker.configuration.data, cooker.status, 
+cooker.build_cache_fail)
         except KeyError:
             lv, lf, pv, pf = (None,)*4
 
